#
# spec file for package Coin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 60

Name:           Coin
Version:        3.1.3
Release:        7.1
Summary:        Scene-graph based retain-mode 3D graphics library
License:        GPL-2.0-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/coin3d/coin/wiki
# The bitbucket site is no longer functional, and the github repo only provides
# tarballs for 3.1.0 and 4.0.0 (and no 3.1.3 tag either).
# Source0:        https://bitbucket.org/Coin3D/coin/downloads/%%{name}-%%{version}.tar.gz
Source0:        %{name}-%{version}.tar.gz
Patch0:         0012-memhandler-initialization.patch
# X-OPENSUSE-PATCH: Coin60.patch -- hack around library policy names
Patch1:         Coin60.patch
Patch2:         Coin.patch
# PATCH-FIX-OPENSUSE -- https://github.com/coin3d/coin/issues/436, fixed with CMake build available with 4.0.0
Patch3:         0001-Actually-link-to-system-expat.patch
BuildRequires:  c++_compiler
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  openal-soft-devel
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xt)

%description
Coin is a scene-graph based, retain-mode, rendering and model
manipulation C++ class library that uses OpenGL for its 3D graphics.
Coin is compatible to Open Inventor 2.1 and also has support for 3D
sound, GLSL shaders, and additional file formats like VRML97.

%package devel
Summary:        Development files for Coin, a 3D graphics library
Group:          Development/Libraries/C and C++
Requires:       fontconfig-devel
Requires:       freetype2-devel
Requires:       libCoin%{soname} = %{version}
Requires:       openal-soft-devel
Requires:       zlib-devel
Requires:       pkgconfig(bzip2)
Requires:       pkgconfig(dri)
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glu)
Requires:       pkgconfig(ice)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xt)

%description devel
Coin is a scene-graph based, retain-mode, rendering and model
manipulation C++ class library that uses OpenGL for its 3D graphics.
Coin is compatible to Open Inventor 2.1 and also has support for 3D
sound, GLSL shaders, and additional file formats like VRML97.

This subpackage contains libraries and header files for developing
applications that want to make use of Coin.

%package -n libCoin%{soname}
Summary:        Scene-graph based retain-mode 3D graphics library
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libCoin%{soname}
Coin is a scene-graph based, retain-mode, rendering and model
manipulation C++ class library that uses OpenGL for its 3D graphics.
Coin is compatible to Open Inventor 2.1 and also has support for 3D
sound, GLSL shaders, and additional file formats like VRML97.

%prep
%autosetup -p1
sed -i '/^#include "fonts\/freetype.h"$/i #include <cstdlib>\n#include <cmath>' src/fonts/freetype.cpp
sed -i '/^#include <Inventor\/C\/basic.h>$/i #include <Inventor/C/errors/debugerror.h>' include/Inventor/SbBasic.h

# Remove build time references so build-compare can do its work
sed -i "s/Generated on \$datetime/Generated/" docs/doxygen/footer.html

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"

%configure \
    --htmldir=%{_docdir}/%{name}-devel/html \
    --enable-3ds-import \
    --enable-javascript-api \
    --enable-threadsafe \
    --enable-html \
    --enable-man \
    --enable-system-expat \
    --disable-dl-openal \
    --disable-dl-fontconfig \
    --disable-dl-freetype \
    --disable-dl-zlib \
    --disable-dl-libbzip2 \
    --disable-dl-glu \
    --with-freetype=%{_prefix}

%make_build

%install
%make_install

# avoid conflicting man page
rm %{buildroot}/usr/share/man/man3/deprecated.*

# Fix rpmlint warning "pkgconfig-invalid-libs-dir". -L${libdir} is already included in the Coin.pc file
sed -i "s/\-L\/usr\/lib64 \-L\/usr\/lib/ /" %{buildroot}%{_libdir}/pkgconfig/Coin.pc

# Fix the libdir
sed -i -e "s,\-L/usr/lib64 \-L/usr/lib,\-L%{_libdir}," %{buildroot}%{_datadir}/Coin%{soname}/conf/coin-default.cfg

# Remove unneeded files
rm -f %{buildroot}%{_libdir}/*.la

%fdupes %{buildroot}/%{_prefix}

%post -n libCoin%{soname} -p /sbin/ldconfig

%postun -n libCoin%{soname} -p /sbin/ldconfig

%files -n libCoin%{soname}
%license LICENSE.GPL
%{_datadir}/Coin%{soname}/
%{_libdir}/libCoin.so.%{soname}*

%files devel
%doc AUTHORS ChangeLog FAQ NEWS README RELNOTES THANKS
%license COPYING FAQ.legal LICENSE.GPL
%{_bindir}/coin-config
%{_includedir}/Inventor/
%{_includedir}/SoDebug.h
%{_includedir}/SoWinEnterScope.h
%{_includedir}/SoWinLeaveScope.h
%{_libdir}/pkgconfig/Coin.pc
%{_libdir}/libCoin.so
%{_datadir}/aclocal/coin.m4
%doc %{_mandir}/man1/coin-config.1%{ext_man}
%doc %{_mandir}/man3/*.3%{ext_man}
%{_docdir}/%{name}-devel/html

%changelog
* Wed May  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup: allows to eliminate usage of deprecated %%patchN
  syntax.
- Rebase Coin60.patch to also apply with -p1.
* Tue Dec 15 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Explicitly request system libexpat. The bundled expat 2.0.1 has
  known vulnerabilities, and also causes crashes in e.g. FreeCADs
  SVG import due to using incompatible expat versions in use at
  the same time (https://tracker.freecadweb.org/view.php?id=3307).
  * 0001-Actually-link-to-system-expat.patch
- Cleanup spec file:
  * Update Homepage URL
  * Remove Source URL, bitbucket download is no longer functional
  * Use %%license, %%make_build, %%make_install macros
* Sun Jul 23 2017 olaf@aepfle.de
- Fix invalid C++ with Coin.patch
* Fri Apr 14 2017 lnussel@suse.de
- Remove obsolete 13.2 patch fix-freetype2-includes.patch, fixes
  build for 42.3
* Thu Mar  9 2017 sfalken@opensuse.org
- Edited %%files to clear unpackaged files builderror in
  openSUSE:Factory
* Sun Oct 30 2016 jengelh@inai.de
- Redo description from in-tarball README
- Run fdupes over entire package
* Mon Aug 15 2016 adrian@suse.de
- install data files into versioned directory
* Sat Jul 30 2016 wk@ire.pw.edu.pl
- Do not use freetype2 patch on Leap 42.2
* Sat Jul 30 2016 adrian@suse.de
- fix file conflict with qwt-devel-doc (deprecated man page)
* Sat Jul  9 2016 dev@stellardeath.org
- Import bugfix from Fedora that corrects a segfault that appears
  with GCC-6 due to an error in Coin,
  * 0012-memhandler-initialization.patch
  More information about this available at
    https://bugzilla.redhat.com/show_bug.cgi?id=1323159#c43
* Tue Jul  5 2016 adrian@suse.de
- fix download url of source tar ball
* Sat Mar 26 2016 wk@ire.pw.edu.pl
- Do not use freetype2 patch on Tumbleweed
* Sun Mar  9 2014 tittiatcoke@gmail.com
- Drop patch gcc-4.7.patch due to upstream inclusion
- Added patch fix-freetype2-includes.patch to fix
  build issues with freetype2
* Sun Oct 28 2012 asterios.dramis@gmail.com
- Added bzip2 as build requirement (needed for Factory).
* Tue Sep 25 2012 asterios.dramis@gmail.com
- Use pkgconfig(...) for Mesa and xorg-x11 build requirements. This fixes also
  compilation in Factory due to the Mesa package changes (with the addition of
  pkgconfig(dri) as build requirement).
* Sat Apr 28 2012 asterios.dramis@gmail.com
- Added the following devel packages as requirements of Coin-devel:
  Mesa-libGL-devel, Mesa-libGLU-devel, fontconfig-devel, freetype2-devel,
  libICE-devel, libX11-devel, libXt-devel, openal-soft-devel and zlib-devel.
* Fri Apr 27 2012 asterios.dramis@gmail.com
- Added a patch to fix compilation with gcc-4.7 (based on a patch from Fedora).
- Link to the needed libraries during compilation instead of using runtime
  linking. This added the following build dependencies:
  Mesa-libGL-devel, Mesa-libGLU-devel, fontconfig-devel, freetype2-devel,
  libICE-devel, libX11-devel, libXt-devel, openal-soft-devel and zlib-devel.
- Removed freeglut-devel dependency (not needed).
- Build development documentation (with doxygen).
- Changed License to GPL-2.0.
- Remove build time references so build-compare can do its work.
- Use the correct arch libdir in Coin.pc and coin-default.cfg files.
* Fri Dec 10 2010 andrea@links2linux.de
- new upstream version 3.1.3
* Sat Sep 26 2009 Andrea Florio <andrea@links2linux.de> 3.1.1
- new upstream version
* Sun Sep 28 2008 Andrea Florio <andrea@links2linux.de>
- complete spec rewrite
* Sun Nov 18 2007 Michal Vyskocil <mvyskocil@suse.cz>
- First release for OpenSuse Build Service
